@@ -144,7 +144,7 @@ class Checker:
                 try:
                     email = combo.split(":")[0]
                     password = combo.split(":")[1]
-                except ValueError:
+                except:
                     email = combo.split(";")[0]
                     password = combo.split(";")[1]
             except queue.Empty:
